/*------------------------------------------------------.
 | Author: Maurizio Loreti, aka MLO or (HAM) I3NOO      |
 | Work:   University of Padova - Department of Physics |
 |         Via F. Marzolo, 8 - 35131 PADOVA - Italy     |
 | Phone:  +39 (049) 827-7216   FAX: +39 (049) 827-7102 |
 | EMail:  loreti@pd.infn.it                            |
 | WWW:    http://www.pd.infn.it/~loreti/mlo.html       |
 `------------------------------------------------------+------------
 Include file for "ce.c": see there for more comments.
 --------------------------------------------------------------------
 $Id: ce.h,v 1.1 2004/02/04 06:59:08 loreti Exp $
 -------------------------------------------------------------------*/

#ifndef CE_H_
#define CE_H_

/**
 | A structure to hold RGB values
**/

typedef struct sRGBdb {
  int r;
  int g;
  int b;
} RGBdb;

/**
 | Shortcuts
**/

#define OK              42
#define ERROR           0

/**
 | Database file:
 | - maximum number of RGB entries in the file;
 | - maximum line length in the file.
**/

#define MAX_RGB         2048
#define MAX_DB_LEN      256

/**
 | Weight factors to define the "distance" between two colors
**/

#define R_FACTOR        3.0
#define G_FACTOR        5.9
#define B_FACTOR        1.1

/**
 | Constants to identify the active slider in the related
 | call-back function
**/

#define RED             0x1
#define GREEN           0x2
#define BLUE            0x3
#define RGB_MASK        0xF

/**
 | Constants to identify the active button in the related
 | call-back function
**/

#define LL              0x10
#define L               0x20
#define S               0x30
#define R               0x40
#define RR              0x50
#define LSR_MASK        0xF0

/**
 | Geometric constants, and other gadget constants
**/

#define FF_W 615                /* Form width and height */
#define FF_H 365

#define MB_X 0                  /* Main box : upper left corner, */
#define MB_Y 0                  /*   width, height and label     */
#define MB_W FF_W
#define MB_H FF_H
#define MB_L ""

#define R_LL_X  20              /* "Red Left-Left" button:  */
#define R_LL_Y  230             /*   upper left corner,     */
#define R_LL_W  30              /*     width, height, label */
#define R_LL_H  30              /*       and call-back ID   */
#define R_LL_L  "@<<"
#define R_LL_CB (RED | LL)

#define R_L_X  60               /* "Red Left" button */
#define R_L_Y  230
#define R_L_W  30
#define R_L_H  30
#define R_L_L  "@<"
#define R_L_CB (RED | L)

#define R_S_X  100              /* "Red" slider */
#define R_S_Y  230
#define R_S_W  200
#define R_S_H  30
#define R_S_L  ""
#define R_S_CB (RED | S)

#define R_R_X  310              /* "Red right" button */
#define R_R_Y  230
#define R_R_W  30
#define R_R_H  30
#define R_R_L  "@>"
#define R_R_CB (RED | R)

#define R_RR_X  350             /* "Red Right-Right" button */
#define R_RR_Y  230
#define R_RR_W  30
#define R_RR_H  30
#define R_RR_L  "@>>"
#define R_RR_CB (RED | RR)

#define G_LL_X  20              /* "Green Left-Left" button: */
#define G_LL_Y  270             /*   upper left corner,      */
#define G_LL_W  30              /*     width, height, label  */
#define G_LL_H  30              /*       and call-back ID    */
#define G_LL_L  "@<<"
#define G_LL_CB (GREEN | LL)

#define G_L_X  60               /* "Green Left" button */
#define G_L_Y  270
#define G_L_W  30
#define G_L_H  30
#define G_L_L  "@<"
#define G_L_CB (GREEN | L)

#define G_S_X  100              /* "Green" slider */
#define G_S_Y  270
#define G_S_W  200
#define G_S_H  30
#define G_S_L  ""
#define G_S_CB (GREEN | S)

#define G_R_X  310              /* "Green right" button */
#define G_R_Y  270
#define G_R_W  30
#define G_R_H  30
#define G_R_L  "@>"
#define G_R_CB (GREEN | R)

#define G_RR_X  350             /* "Green Right-Right" button */
#define G_RR_Y  270
#define G_RR_W  30
#define G_RR_H  30
#define G_RR_L  "@>>"
#define G_RR_CB (GREEN | RR)

#define B_LL_X  20              /* "Blue Left-Left" button: */
#define B_LL_Y  310             /*   upper left corner,     */
#define B_LL_W  30              /*     width, height, label */
#define B_LL_H  30              /*       and call-back ID   */
#define B_LL_L  "@<<"
#define B_LL_CB (BLUE | LL)

#define B_L_X  60               /* "Blue Left" button */
#define B_L_Y  310
#define B_L_W  30
#define B_L_H  30
#define B_L_L  "@<"
#define B_L_CB (BLUE | L)

#define B_S_X  100              /* "Blue" slider */
#define B_S_Y  310
#define B_S_W  200
#define B_S_H  30
#define B_S_L  ""
#define B_S_CB (BLUE | S)

#define B_R_X  310              /* "Blue right" button */
#define B_R_Y  310
#define B_R_W  30
#define B_R_H  30
#define B_R_L  "@>"
#define B_R_CB (BLUE | R)

#define B_RR_X  350             /* "Blue Right-Right" button */
#define B_RR_Y  310
#define B_RR_W  30
#define B_RR_H  30
#define B_RR_L  "@>>"
#define B_RR_CB (BLUE | RR)

#define CB_X 320                /* "Color show" box */
#define CB_Y 60
#define CB_W 270
#define CB_H 150
#define CB_L ""

#define RV_X 410                /* Red values */
#define RV_Y 225
#define RV_W 180
#define RV_H 40

#define GV_X 410                /* Green values */
#define GV_Y 265
#define GV_W 180
#define GV_H 40

#define BV_X 410                /* Blue values */
#define BV_Y 305
#define BV_W 180
#define BV_H 40

#define DBN_X  20               /* Database name */
#define DBN_Y  20
#define DBN_W  280
#define DBN_H  30
#define DBN_CB 1

#define DBB_X    20             /* Database browser */
#define DBB_Y    60
#define DBB_W    280
#define DBB_H    150
#define DBB_CB   2
#define BR_LINES 14

#define EB_X  460               /* EXIT button */
#define EB_Y  20
#define EB_W  130
#define EB_H  30
#define EB_L  "EXIT"
#define EB_CB -1

#define FN_X  320               /* "Find nearer" button */
#define FN_Y  20
#define FN_W  130
#define FN_H  30
#define FN_L  "Find nearer"
#define FN_CB 3

#endif /* CE_H_ */
